
RELEASE_VERSION='0.3.1078465524'
BUILD_DATE='Mon Nov 20 09:36:37 UTC 2023'
BUILD_MACHINE_INFO='Linux runner-v5xuvete-project-28359933-concurrent-099w8b 5.4.235-144.344.amzn2.x86_64 #1 SMP Sun Mar 12 12:50:22 UTC 2023 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='5574034335'
GIT_COMMIT_SHA='7737cdd01e29b4f6d62594352bc722b11c7e8559'
GIT_BRANCH='main'
